function [ g ] = double_gaussian( p, pstar, w1, w2, alpha )
% -------------------------------------------------------------------------
%
% NAME
%
%	double_gaussian
%
% PURPOSE
%
%	This routine creates a double Gaussian with the prescribed parameters.
%
% CALLING SEQUENCE
%
%	[ g ] = double_gaussian( p, pstar, w1, w2, alpha )
%
% INPUT PARAMETERS
%   
%   p
%     pixel vector
%
%   pstar
%     position of the centre of the ion beam
%
%   w1, w2, alpha
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian
%
% OUTPUT PARAMETERS
%
%   g
%     double gaussian profile, same format as p
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------

    % Combine two gaussian components
    g = ( 1 - alpha ) * gaussian( p, pstar, w1 ) + alpha * gaussian( p, pstar, w2 );
    
end

function [ g ] = gaussian( p, pstar, w )
    % Evaluate gaussian
    % Accelerate by checking whether exp(-mu^2) > 1e-99
    % which happens for mu < 15 approximately
    mu = ( p - pstar )/w;
    g = 0*p;
    selection = ( abs(mu) < 15 );
    g(selection) = exp( -mu(selection).^2 );
end

% =========================================================================
